@@ -2,6 +2,7 @@
 #
 # This file is part of Invenio.
 # Copyright (C) 2015-2018 CERN.
+# Copyright (C) 2022 RERO.
 #
 # Invenio is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
@@ -13,11 +14,12 @@ from __future__ import absolute_import, print_function
 import os
 import warnings
 
+import importlib_metadata
 import oauthlib.common as oauthlib_commmon
-import pkg_resources
 import six
 from flask import abort, request
 from flask_login import current_user
+from invenio_rest.csrf import csrf
 from werkzeug.utils import cached_property, import_string
 
 from . import config
@@ -87,7 +89,9 @@ class _OAuth2ServerState(object):
 
         :param entry_point_group: The entrypoint group name to load plugins.
         """
-        for ep in pkg_resources.iter_entry_points(group=entry_point_group):
+        for ep in set(importlib_metadata.entry_points(
+            group=entry_point_group
+        )):
             self.register_scope(ep.load())
 
     def load_obj_or_import_string(self, value):
@@ -172,6 +176,11 @@ def verify_oauth_token_and_set_current_user():
 
         app.before_request(verify_oauth_token_and_set_current_user)
     """
+    # Since this function can be evoked multiple times
+    # we add a check to not run it if it has already run.
+    if hasattr(request, 'oauth_verify_has_run'):
+        return
+
     for func in oauth2._before_request_funcs:
         func()
 
@@ -188,6 +197,11 @@ def verify_oauth_token_and_set_current_user():
         if valid:
             request.oauth = req
 
+    if hasattr(request, 'oauth'):
+        request.skip_csrf_check = True
+
+    request.oauth_verify_has_run = True
+
 
 class InvenioOAuth2ServerREST(object):
     """Invenio-OAuth2Server REST extension."""
@@ -212,6 +226,8 @@ class InvenioOAuth2ServerREST(object):
         if allowed_urlencode_chars:
             InvenioOAuth2ServerREST.monkeypatch_oauthlib_urlencode_chars(
                 allowed_urlencode_chars)
+        # add check to skip csrf validation if oauth request
+        csrf.before_csrf_protect(verify_oauth_token_and_set_current_user)
         app.before_request(verify_oauth_token_and_set_current_user)
 
     def init_config(self, app):
