@@ -14,6 +14,7 @@ from __future__ import absolute_import, print_function
 import os
 import shutil
 import tempfile
+from unittest.mock import MagicMock
 
 import pytest
 from flask import Flask, url_for
@@ -28,11 +29,9 @@ from invenio_accounts import InvenioAccountsREST, InvenioAccountsUI
 from invenio_accounts.models import User
 from invenio_accounts.views import blueprint as accounts_blueprint
 from invenio_db import InvenioDB, db
-from mock import MagicMock
 from six import get_method_self
 from sqlalchemy_utils.functions import create_database, database_exists, \
     drop_database
-from werkzeug.wsgi import DispatcherMiddleware
 
 from invenio_oauth2server import InvenioOAuth2Server, InvenioOAuth2ServerREST
 from invenio_oauth2server.decorators import require_api_auth, \
@@ -40,6 +39,13 @@ from invenio_oauth2server.decorators import require_api_auth, \
 from invenio_oauth2server.models import Client, Scope, Token
 from invenio_oauth2server.views import server_blueprint, settings_blueprint
 
+import invenio_oauth2server._compat  # noqa isort:skip
+
+try:
+    from werkzeug.middleware.dispatcher import DispatcherMiddleware
+except ImportError:
+    from werkzeug.wsgi import DispatcherMiddleware
+
 
 @pytest.fixture()
 def app(request):
@@ -48,6 +54,7 @@ def app(request):
 
     def init_app(app):
         app.config.update(
+            DB_VERSIONING=True,
             LOGIN_DISABLED=False,
             MAIL_SUPPRESS_SEND=True,
             OAUTH2_CACHE_TYPE='simple',
@@ -64,6 +71,19 @@ def app(request):
             SQLALCHEMY_TRACK_MODIFICATIONS=True,
             TESTING=True,
             WTF_CSRF_ENABLED=False,
+            APP_THEME="semantic-ui",
+            THEME_ICONS={
+                'semantic-ui': {
+                    'key': 'key icon',
+                    'link': 'linkify icon',
+                    'shield': 'shield alternate icon',
+                    'user': 'user icon',
+                    'codepen': 'codepen icon',
+                    'cogs': 'cogs icon',
+                    # Special catch all:
+                    '*': '{} icon'
+                }
+            },
         )
         Babel(app)
         Mail(app)
@@ -94,8 +114,8 @@ def app(request):
 
     with app.app_context():
         if str(db.engine.url) != 'sqlite://' and \
-           not database_exists(str(db.engine.url)):
-                create_database(str(db.engine.url))
+                not database_exists(str(db.engine.url)):
+            create_database(str(db.engine.url))
         db.create_all()
 
     def teardown():
@@ -116,6 +136,7 @@ def api_app(app):
 
 @pytest.fixture()
 def api_app_with_test_view(api_app):
+    """Add a test view URL."""
     api_app.add_url_rule('/test', 'test', view_func=lambda: 'OK')
     return api_app
 
@@ -253,6 +274,7 @@ def models_fixture(app):
 def provider_fixture(app):
     """Fixture that contains test data for provider tests."""
     from invenio_oauth2server.proxies import current_oauth2server
+
     # Mock the oauth client calls to prevent them from going online.
     oauth_client = create_oauth_client(app, 'oauth2test')
     oauth_client.http_request = MagicMock(
@@ -346,6 +368,7 @@ def provider_fixture(app):
 def resource_fixture(app, api_app):
     """Fixture that contains the test data for models tests."""
     from flask import g, request
+
     from invenio_oauth2server.proxies import current_oauth2server
 
     # Setup API resources
